@@ -20,13 +20,7 @@
 #include <unistd.h>
 #include <assert.h>
 
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wpedantic"
-#include <ell/queue.h>
-#include <ell/hashmap.h>
-#include <ell/util.h>
-#include <ell/log.h>
-#pragma GCC diagnostic pop
+#include <ell/ell.h>
 
 /**
  * @todo Remove this preprocessor symbol definition once support for
@@ -290,7 +284,7 @@ static void load_plugin(char const *filename)
 static void load_plugins_queue(char const *dir,
                                struct l_queue const* plugins_to_load)
 {
-        struct l_queue_entry const *entry = 
+        struct l_queue_entry const *entry =
                 l_queue_get_entries((struct l_queue *) plugins_to_load);
 
         while (entry) {
@@ -359,8 +353,8 @@ static int load_plugins_all(int const fd,
 }
 
 
-static int load_plugins(char const *dir, 
-                        struct l_queue const *plugins_to_load, 
+static int load_plugins(char const *dir,
+                        struct l_queue const *plugins_to_load,
                         struct mptcpd_pm *pm)
 {
         /**
@@ -679,6 +673,28 @@ void mptcpd_plugin_subflow_priority(mptcpd_token_t token,
 
 }
 
+void mptcpd_plugin_listener_created(char const *name,
+                                    struct sockaddr const *laddr,
+                                    struct mptcpd_pm *pm)
+{
+        struct mptcpd_plugin_ops const *const ops = name_to_ops(name);
+
+        if (ops && ops->listener_created)
+                ops->listener_created(laddr, pm);
+
+}
+
+void mptcpd_plugin_listener_closed(char const *name,
+                                   struct sockaddr const *laddr,
+                                   struct mptcpd_pm *pm)
+{
+        struct mptcpd_plugin_ops const *const ops = name_to_ops(name);
+
+        if (ops && ops->listener_closed)
+                ops->listener_closed(laddr, pm);
+
+}
+
 // ----------------------------------------------------------------
 // Network Monitoring Related Plugin Operation Callback Invocation
 // ----------------------------------------------------------------
