@@ -11,12 +11,7 @@
 #include <netinet/in.h>
 #include <sys/un.h>
 
-#pragma GCC diagnostic push
-#pragma GCC diagnostic ignored "-Wpedantic"
-#include <ell/util.h>
-#include <ell/log.h>
-#include <ell/test.h>
-#pragma GCC diagnostic pop
+#include <ell/ell.h>
 
 #include <mptcpd/private/listener_manager.h>
 #include <mptcpd/listener_manager.h>
